
Utility Functions/Classes
++++++++++++++++++++++++++

Custom Datatypes
-----------------

.. automodule:: masci_tools.util.lockable_containers
   :members:

.. automodule:: masci_tools.util.case_insensitive_dict
   :members:

Common XML utility
------------------

.. automodule:: masci_tools.util.xml.common_functions
   :members:

.. automodule:: masci_tools.util.xml.converters
   :members:

XML Setter functions
---------------------

.. automodule:: masci_tools.util.xml.xml_setters_names
   :members:

.. automodule:: masci_tools.util.xml.xml_setters_nmmpmat
   :members:

.. automodule:: masci_tools.util.xml.xml_setters_xpaths
   :members:

.. automodule:: masci_tools.util.xml.xml_setters_basic
   :members:

XML Getter functions
---------------------

.. automodule:: masci_tools.util.xml.xml_getters
   :members:

Basic IO helper functions
---------------------------

.. automodule:: masci_tools.io.common_functions
   :members:

.. automodule:: masci_tools.io.hdf5_util
   :members:

Logging Utility
----------------

.. automodule:: masci_tools.util.logging_util
   :members:

Fleur parser utility
----------------------

.. automodule:: masci_tools.util.schema_dict_util
   :members:

.. automodule:: masci_tools.util.fleur_calculate_expression
   :members:

.. automodule:: masci_tools.util.parse_tasks
   :members:

.. automodule:: masci_tools.util.parse_tasks_decorators
   :members:

.. automodule:: masci_tools.io.parsers.fleur.outxml_conversions
   :members:


Basic Fleur Schema parser functions
++++++++++++++++++++++++++++++++++++

.. automodule:: masci_tools.io.parsers.fleur.fleur_schema
   :members:

.. automodule:: masci_tools.io.parsers.fleur.fleur_schema.fleur_schema_parser_functions
   :members:


Defined constants
++++++++++++++++++++

.. automodule:: masci_tools.util.constants
